@@ -16,15 +16,16 @@ class Band(OutObject):
     """Base class for Band Designation"""
 
     def __init__(self, frequency):
-        self.is_2ghz = is_two_four_band(int(frequency))
-        self.is_5ghz = is_five_band(int(frequency))
-        self.is_6ghz = is_six_band(int(frequency))
-        if self.is_2ghz:
-            band = "2GHz"
-        if self.is_5ghz:
-            band = "5GHz"
+        self.is_2ghz = is_two_four_band(frequency)
+        self.is_5ghz = is_five_band(frequency)
+        self.is_6ghz = is_six_band(frequency)
+        band = None
         if self.is_6ghz:
             band = "6GHz"
+        if self.is_5ghz:
+            band = "5GHz"
+        if self.is_2ghz:
+            band = "2GHz"
         if band:
             self.value = band
         else:
